from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

MCU_ST_STM8 = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'STM8AF6223', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM8AF6223'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'STM8 Microcontroller Automotive Line', 'description':'', 'datasheet':'http://www.st.com/resource/en/datasheet/stm8af6223.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM8.kicad_sym\nSTM8AF6223\n\nSTM8 Microcontroller Automotive Line', 'pins':[
            Pin(num='1',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VCAP',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM8AF6223A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM8AF6223A'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'STM8 Microcontroller Automotive Line', 'description':'', 'datasheet':'http://www.st.com/resource/en/datasheet/stm8af6223.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM8.kicad_sym\nSTM8AF6223A\n\nSTM8 Microcontroller Automotive Line', 'pins':[
            Pin(num='1',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VCAP',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM8AL3188T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM8AL3188T'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'STM8 automotive ultra-low-power', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm8al3188.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM8.kicad_sym\nSTM8AL3188T\n\nSTM8 automotive ultra-low-power', 'pins':[
            Pin(num='1',name='PA0',func=pin_types.BIDIR),
            Pin(num='10',name='VDD1',func=pin_types.PWRIN),
            Pin(num='11',name='VDDA',func=pin_types.PWRIN),
            Pin(num='12',name='VREF+',func=pin_types.PWRIN),
            Pin(num='13',name='RES1',func=pin_types.PWRIN),
            Pin(num='14',name='PE0',func=pin_types.BIDIR),
            Pin(num='15',name='PE1',func=pin_types.BIDIR),
            Pin(num='16',name='PE2',func=pin_types.BIDIR),
            Pin(num='17',name='PE3',func=pin_types.BIDIR),
            Pin(num='18',name='PE4',func=pin_types.BIDIR),
            Pin(num='19',name='PE5',func=pin_types.BIDIR),
            Pin(num='2',name='NRST/PA1',func=pin_types.BIDIR),
            Pin(num='20',name='PD0',func=pin_types.BIDIR),
            Pin(num='21',name='PD1',func=pin_types.BIDIR),
            Pin(num='22',name='PD2',func=pin_types.BIDIR),
            Pin(num='23',name='PD3',func=pin_types.BIDIR),
            Pin(num='24',name='PB0',func=pin_types.BIDIR),
            Pin(num='25',name='PB1',func=pin_types.BIDIR),
            Pin(num='26',name='PB2',func=pin_types.BIDIR),
            Pin(num='27',name='PB3',func=pin_types.BIDIR),
            Pin(num='28',name='PB4',func=pin_types.BIDIR),
            Pin(num='29',name='PB5',func=pin_types.BIDIR),
            Pin(num='3',name='PA2',func=pin_types.BIDIR),
            Pin(num='30',name='PB6',func=pin_types.BIDIR),
            Pin(num='31',name='PB7',func=pin_types.BIDIR),
            Pin(num='32',name='PF0',func=pin_types.BIDIR),
            Pin(num='33',name='PD4',func=pin_types.BIDIR),
            Pin(num='34',name='PD5',func=pin_types.BIDIR),
            Pin(num='35',name='PD6',func=pin_types.BIDIR),
            Pin(num='36',name='PD7',func=pin_types.BIDIR),
            Pin(num='37',name='PC0',func=pin_types.BIDIR),
            Pin(num='38',name='PC1',func=pin_types.BIDIR),
            Pin(num='39',name='VDD2',func=pin_types.PWRIN),
            Pin(num='4',name='PA3',func=pin_types.BIDIR),
            Pin(num='40',name='VSS2',func=pin_types.PWRIN),
            Pin(num='41',name='PC2',func=pin_types.BIDIR),
            Pin(num='42',name='PC3',func=pin_types.BIDIR),
            Pin(num='43',name='PC4',func=pin_types.BIDIR),
            Pin(num='44',name='PC5',func=pin_types.BIDIR),
            Pin(num='45',name='PC6',func=pin_types.BIDIR),
            Pin(num='46',name='PC7',func=pin_types.BIDIR),
            Pin(num='47',name='PE6',func=pin_types.BIDIR),
            Pin(num='48',name='PE7',func=pin_types.BIDIR),
            Pin(num='5',name='PA4',func=pin_types.BIDIR),
            Pin(num='6',name='PA5',func=pin_types.BIDIR),
            Pin(num='7',name='PA6',func=pin_types.BIDIR),
            Pin(num='8',name='PA7',func=pin_types.BIDIR),
            Pin(num='9',name='VSS1/VSSA/VREF-',func=pin_types.PWRIN)], 'unit_defs':[] }),
        Part(**{ 'name':'STM8AL3189T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM8AL3189T'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'STM8 automotive ultra-low-power', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm8al3188.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM8.kicad_sym\nSTM8AL3189T\n\nSTM8 automotive ultra-low-power', 'pins':[
            Pin(num='1',name='PA0',func=pin_types.BIDIR),
            Pin(num='10',name='VSS1',func=pin_types.PWRIN),
            Pin(num='11',name='VDD1',func=pin_types.PWRIN),
            Pin(num='12',name='VDDA',func=pin_types.PWRIN),
            Pin(num='13',name='VREF+',func=pin_types.PWRIN),
            Pin(num='14',name='PG0',func=pin_types.BIDIR),
            Pin(num='15',name='PG1',func=pin_types.BIDIR),
            Pin(num='16',name='PG2',func=pin_types.BIDIR),
            Pin(num='17',name='PG3',func=pin_types.BIDIR),
            Pin(num='18',name='RES1',func=pin_types.PWRIN),
            Pin(num='19',name='PE0',func=pin_types.BIDIR),
            Pin(num='2',name='NRST/PA1',func=pin_types.BIDIR),
            Pin(num='20',name='PE1',func=pin_types.BIDIR),
            Pin(num='21',name='PE2',func=pin_types.BIDIR),
            Pin(num='22',name='PE3',func=pin_types.BIDIR),
            Pin(num='23',name='PE4',func=pin_types.BIDIR),
            Pin(num='24',name='PE5',func=pin_types.BIDIR),
            Pin(num='25',name='PD0',func=pin_types.BIDIR),
            Pin(num='26',name='PD1',func=pin_types.BIDIR),
            Pin(num='27',name='PD2',func=pin_types.BIDIR),
            Pin(num='28',name='PD3',func=pin_types.BIDIR),
            Pin(num='29',name='VDD3',func=pin_types.PWRIN),
            Pin(num='3',name='PA2',func=pin_types.BIDIR),
            Pin(num='30',name='VSS3',func=pin_types.PWRIN),
            Pin(num='31',name='PB0',func=pin_types.BIDIR),
            Pin(num='32',name='PB1',func=pin_types.BIDIR),
            Pin(num='33',name='PB2',func=pin_types.BIDIR),
            Pin(num='34',name='PB3',func=pin_types.BIDIR),
            Pin(num='35',name='PB4',func=pin_types.BIDIR),
            Pin(num='36',name='PB5',func=pin_types.BIDIR),
            Pin(num='37',name='PB6',func=pin_types.BIDIR),
            Pin(num='38',name='PB7',func=pin_types.BIDIR),
            Pin(num='39',name='PF0',func=pin_types.BIDIR),
            Pin(num='4',name='PA3',func=pin_types.BIDIR),
            Pin(num='40',name='PF1',func=pin_types.BIDIR),
            Pin(num='41',name='PF4',func=pin_types.BIDIR),
            Pin(num='42',name='PF5',func=pin_types.BIDIR),
            Pin(num='43',name='PF6',func=pin_types.BIDIR),
            Pin(num='44',name='PF7',func=pin_types.BIDIR),
            Pin(num='45',name='PD4',func=pin_types.BIDIR),
            Pin(num='46',name='PD5',func=pin_types.BIDIR),
            Pin(num='47',name='PD6',func=pin_types.BIDIR),
            Pin(num='48',name='PD7',func=pin_types.BIDIR),
            Pin(num='49',name='PG4',func=pin_types.BIDIR),
            Pin(num='5',name='PA4',func=pin_types.BIDIR),
            Pin(num='50',name='PG5',func=pin_types.BIDIR),
            Pin(num='51',name='PG6',func=pin_types.BIDIR),
            Pin(num='52',name='PG7',func=pin_types.BIDIR),
            Pin(num='53',name='PC0',func=pin_types.BIDIR),
            Pin(num='54',name='PC1',func=pin_types.BIDIR),
            Pin(num='55',name='VDD2',func=pin_types.PWRIN),
            Pin(num='56',name='VSS2',func=pin_types.PWRIN),
            Pin(num='57',name='PC2',func=pin_types.BIDIR),
            Pin(num='58',name='PC3',func=pin_types.BIDIR),
            Pin(num='59',name='PC4',func=pin_types.BIDIR),
            Pin(num='6',name='PA5',func=pin_types.BIDIR),
            Pin(num='60',name='PC5',func=pin_types.BIDIR),
            Pin(num='61',name='PC6',func=pin_types.BIDIR),
            Pin(num='62',name='PC7',func=pin_types.BIDIR),
            Pin(num='63',name='PE6',func=pin_types.BIDIR),
            Pin(num='64',name='PE7',func=pin_types.BIDIR),
            Pin(num='7',name='PA6',func=pin_types.BIDIR),
            Pin(num='8',name='PA7',func=pin_types.BIDIR),
            Pin(num='9',name='VSSA/VREF-',func=pin_types.PWRIN)], 'unit_defs':[] }),
        Part(**{ 'name':'STM8AL318AT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM8AL318AT'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-80_14x14mm_P0.65mm'], 'footprint':'Package_QFP:LQFP-80_14x14mm_P0.65mm', 'keywords':'STM8 automotive ultra-low-power', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm8al3188.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM8.kicad_sym\nSTM8AL318AT\n\nSTM8 automotive ultra-low-power', 'pins':[
            Pin(num='1',name='PH0',func=pin_types.BIDIR),
            Pin(num='10',name='PA5',func=pin_types.BIDIR),
            Pin(num='11',name='PA6',func=pin_types.BIDIR),
            Pin(num='12',name='PA7',func=pin_types.BIDIR),
            Pin(num='13',name='VSSA/VREF-',func=pin_types.PWRIN),
            Pin(num='14',name='VSS1',func=pin_types.PWRIN),
            Pin(num='15',name='VDD1',func=pin_types.PWRIN),
            Pin(num='16',name='VDDA',func=pin_types.PWRIN),
            Pin(num='17',name='VREF+',func=pin_types.PWRIN),
            Pin(num='18',name='PG0',func=pin_types.BIDIR),
            Pin(num='19',name='PG1',func=pin_types.BIDIR),
            Pin(num='2',name='PH1',func=pin_types.BIDIR),
            Pin(num='20',name='PG2',func=pin_types.BIDIR),
            Pin(num='21',name='PG3',func=pin_types.BIDIR),
            Pin(num='22',name='RES1',func=pin_types.PWRIN),
            Pin(num='23',name='PE0',func=pin_types.BIDIR),
            Pin(num='24',name='PE1',func=pin_types.BIDIR),
            Pin(num='25',name='PE2',func=pin_types.BIDIR),
            Pin(num='26',name='PE3',func=pin_types.BIDIR),
            Pin(num='27',name='PE4',func=pin_types.BIDIR),
            Pin(num='28',name='PE5',func=pin_types.BIDIR),
            Pin(num='29',name='PD0',func=pin_types.BIDIR),
            Pin(num='3',name='PH2',func=pin_types.BIDIR),
            Pin(num='30',name='PD1',func=pin_types.BIDIR),
            Pin(num='31',name='PD2',func=pin_types.BIDIR),
            Pin(num='32',name='PD3',func=pin_types.BIDIR),
            Pin(num='33',name='PH4',func=pin_types.BIDIR),
            Pin(num='34',name='PH5',func=pin_types.BIDIR),
            Pin(num='35',name='PH6',func=pin_types.BIDIR),
            Pin(num='36',name='PH7',func=pin_types.BIDIR),
            Pin(num='37',name='VDD3',func=pin_types.PWRIN),
            Pin(num='38',name='VSS3',func=pin_types.PWRIN),
            Pin(num='39',name='PB0',func=pin_types.BIDIR),
            Pin(num='4',name='PH3',func=pin_types.BIDIR),
            Pin(num='40',name='PB1',func=pin_types.BIDIR),
            Pin(num='41',name='PB2',func=pin_types.BIDIR),
            Pin(num='42',name='PB3',func=pin_types.BIDIR),
            Pin(num='43',name='PB4',func=pin_types.BIDIR),
            Pin(num='44',name='PB5',func=pin_types.BIDIR),
            Pin(num='45',name='PB6',func=pin_types.BIDIR),
            Pin(num='46',name='PB7',func=pin_types.BIDIR),
            Pin(num='47',name='VDD4',func=pin_types.PWRIN),
            Pin(num='48',name='VSS4',func=pin_types.PWRIN),
            Pin(num='49',name='PF0',func=pin_types.BIDIR),
            Pin(num='5',name='PA0',func=pin_types.BIDIR),
            Pin(num='50',name='PF1',func=pin_types.BIDIR),
            Pin(num='51',name='PF2',func=pin_types.BIDIR),
            Pin(num='52',name='PF3',func=pin_types.BIDIR),
            Pin(num='53',name='PF4',func=pin_types.BIDIR),
            Pin(num='54',name='PF5',func=pin_types.BIDIR),
            Pin(num='55',name='PF6',func=pin_types.BIDIR),
            Pin(num='56',name='PF7',func=pin_types.BIDIR),
            Pin(num='57',name='PD4',func=pin_types.BIDIR),
            Pin(num='58',name='PD5',func=pin_types.BIDIR),
            Pin(num='59',name='PD6',func=pin_types.BIDIR),
            Pin(num='6',name='NRST/PA1',func=pin_types.BIDIR),
            Pin(num='60',name='PD7',func=pin_types.BIDIR),
            Pin(num='61',name='PG4',func=pin_types.BIDIR),
            Pin(num='62',name='PG5',func=pin_types.BIDIR),
            Pin(num='63',name='PG6',func=pin_types.BIDIR),
            Pin(num='64',name='PG7',func=pin_types.BIDIR),
            Pin(num='65',name='PC0',func=pin_types.BIDIR),
            Pin(num='66',name='PC1',func=pin_types.BIDIR),
            Pin(num='67',name='VDD2',func=pin_types.PWRIN),
            Pin(num='68',name='VSS2',func=pin_types.PWRIN),
            Pin(num='69',name='PC2',func=pin_types.BIDIR),
            Pin(num='7',name='PA2',func=pin_types.BIDIR),
            Pin(num='70',name='PC3',func=pin_types.BIDIR),
            Pin(num='71',name='PC4',func=pin_types.BIDIR),
            Pin(num='72',name='PC5',func=pin_types.BIDIR),
            Pin(num='73',name='PC6',func=pin_types.BIDIR),
            Pin(num='74',name='PC7',func=pin_types.BIDIR),
            Pin(num='75',name='PE6',func=pin_types.BIDIR),
            Pin(num='76',name='PE7',func=pin_types.BIDIR),
            Pin(num='77',name='PI0',func=pin_types.BIDIR),
            Pin(num='78',name='PI1',func=pin_types.BIDIR),
            Pin(num='79',name='PI2',func=pin_types.BIDIR),
            Pin(num='8',name='PA3',func=pin_types.BIDIR),
            Pin(num='80',name='PI3',func=pin_types.BIDIR),
            Pin(num='9',name='PA4',func=pin_types.BIDIR)], 'unit_defs':[] }),
        Part(**{ 'name':'STM8AL3L88T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM8AL3L88T'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'STM8 automotive ultra-low-power', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm8al3188.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM8.kicad_sym\nSTM8AL3L88T\n\nSTM8 automotive ultra-low-power', 'pins':[
            Pin(num='1',name='PA0',func=pin_types.BIDIR),
            Pin(num='10',name='VDD1',func=pin_types.PWRIN),
            Pin(num='11',name='VDDA',func=pin_types.PWRIN),
            Pin(num='12',name='VREF+',func=pin_types.PWRIN),
            Pin(num='13',name='VLCD',func=pin_types.PWRIN),
            Pin(num='14',name='PE0',func=pin_types.BIDIR),
            Pin(num='15',name='PE1',func=pin_types.BIDIR),
            Pin(num='16',name='PE2',func=pin_types.BIDIR),
            Pin(num='17',name='PE3',func=pin_types.BIDIR),
            Pin(num='18',name='PE4',func=pin_types.BIDIR),
            Pin(num='19',name='PE5',func=pin_types.BIDIR),
            Pin(num='2',name='NRST/PA1',func=pin_types.BIDIR),
            Pin(num='20',name='PD0',func=pin_types.BIDIR),
            Pin(num='21',name='PD1',func=pin_types.BIDIR),
            Pin(num='22',name='PD2',func=pin_types.BIDIR),
            Pin(num='23',name='PD3',func=pin_types.BIDIR),
            Pin(num='24',name='PB0',func=pin_types.BIDIR),
            Pin(num='25',name='PB1',func=pin_types.BIDIR),
            Pin(num='26',name='PB2',func=pin_types.BIDIR),
            Pin(num='27',name='PB3',func=pin_types.BIDIR),
            Pin(num='28',name='PB4',func=pin_types.BIDIR),
            Pin(num='29',name='PB5',func=pin_types.BIDIR),
            Pin(num='3',name='PA2',func=pin_types.BIDIR),
            Pin(num='30',name='PB6',func=pin_types.BIDIR),
            Pin(num='31',name='PB7',func=pin_types.BIDIR),
            Pin(num='32',name='PF0',func=pin_types.BIDIR),
            Pin(num='33',name='PD4',func=pin_types.BIDIR),
            Pin(num='34',name='PD5',func=pin_types.BIDIR),
            Pin(num='35',name='PD6',func=pin_types.BIDIR),
            Pin(num='36',name='PD7',func=pin_types.BIDIR),
            Pin(num='37',name='PC0',func=pin_types.BIDIR),
            Pin(num='38',name='PC1',func=pin_types.BIDIR),
            Pin(num='39',name='VDD2',func=pin_types.PWRIN),
            Pin(num='4',name='PA3',func=pin_types.BIDIR),
            Pin(num='40',name='VSS2',func=pin_types.PWRIN),
            Pin(num='41',name='PC2',func=pin_types.BIDIR),
            Pin(num='42',name='PC3',func=pin_types.BIDIR),
            Pin(num='43',name='PC4',func=pin_types.BIDIR),
            Pin(num='44',name='PC5',func=pin_types.BIDIR),
            Pin(num='45',name='PC6',func=pin_types.BIDIR),
            Pin(num='46',name='PC7',func=pin_types.BIDIR),
            Pin(num='47',name='PE6',func=pin_types.BIDIR),
            Pin(num='48',name='PE7',func=pin_types.BIDIR),
            Pin(num='5',name='PA4',func=pin_types.BIDIR),
            Pin(num='6',name='PA5',func=pin_types.BIDIR),
            Pin(num='7',name='PA6',func=pin_types.BIDIR),
            Pin(num='8',name='PA7',func=pin_types.BIDIR),
            Pin(num='9',name='VSS1/VSSA/VREF-',func=pin_types.PWRIN)], 'unit_defs':[] }),
        Part(**{ 'name':'STM8AL3L89T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM8AL3L89T'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'STM8 automotive ultra-low-power', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm8al3188.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM8.kicad_sym\nSTM8AL3L89T\n\nSTM8 automotive ultra-low-power', 'pins':[
            Pin(num='1',name='PA0',func=pin_types.BIDIR),
            Pin(num='10',name='VSS1',func=pin_types.PWRIN),
            Pin(num='11',name='VDD1',func=pin_types.PWRIN),
            Pin(num='12',name='VDDA',func=pin_types.PWRIN),
            Pin(num='13',name='VREF+',func=pin_types.PWRIN),
            Pin(num='14',name='PG0',func=pin_types.BIDIR),
            Pin(num='15',name='PG1',func=pin_types.BIDIR),
            Pin(num='16',name='PG2',func=pin_types.BIDIR),
            Pin(num='17',name='PG3',func=pin_types.BIDIR),
            Pin(num='18',name='VLCD',func=pin_types.PWRIN),
            Pin(num='19',name='PE0',func=pin_types.BIDIR),
            Pin(num='2',name='NRST/PA1',func=pin_types.BIDIR),
            Pin(num='20',name='PE1',func=pin_types.BIDIR),
            Pin(num='21',name='PE2',func=pin_types.BIDIR),
            Pin(num='22',name='PE3',func=pin_types.BIDIR),
            Pin(num='23',name='PE4',func=pin_types.BIDIR),
            Pin(num='24',name='PE5',func=pin_types.BIDIR),
            Pin(num='25',name='PD0',func=pin_types.BIDIR),
            Pin(num='26',name='PD1',func=pin_types.BIDIR),
            Pin(num='27',name='PD2',func=pin_types.BIDIR),
            Pin(num='28',name='PD3',func=pin_types.BIDIR),
            Pin(num='29',name='VDD3',func=pin_types.PWRIN),
            Pin(num='3',name='PA2',func=pin_types.BIDIR),
            Pin(num='30',name='VSS3',func=pin_types.PWRIN),
            Pin(num='31',name='PB0',func=pin_types.BIDIR),
            Pin(num='32',name='PB1',func=pin_types.BIDIR),
            Pin(num='33',name='PB2',func=pin_types.BIDIR),
            Pin(num='34',name='PB3',func=pin_types.BIDIR),
            Pin(num='35',name='PB4',func=pin_types.BIDIR),
            Pin(num='36',name='PB5',func=pin_types.BIDIR),
            Pin(num='37',name='PB6',func=pin_types.BIDIR),
            Pin(num='38',name='PB7',func=pin_types.BIDIR),
            Pin(num='39',name='PF0',func=pin_types.BIDIR),
            Pin(num='4',name='PA3',func=pin_types.BIDIR),
            Pin(num='40',name='PF1',func=pin_types.BIDIR),
            Pin(num='41',name='PF4',func=pin_types.BIDIR),
            Pin(num='42',name='PF5',func=pin_types.BIDIR),
            Pin(num='43',name='PF6',func=pin_types.BIDIR),
            Pin(num='44',name='PF7',func=pin_types.BIDIR),
            Pin(num='45',name='PD4',func=pin_types.BIDIR),
            Pin(num='46',name='PD5',func=pin_types.BIDIR),
            Pin(num='47',name='PD6',func=pin_types.BIDIR),
            Pin(num='48',name='PD7',func=pin_types.BIDIR),
            Pin(num='49',name='PG4',func=pin_types.BIDIR),
            Pin(num='5',name='PA4',func=pin_types.BIDIR),
            Pin(num='50',name='PG5',func=pin_types.BIDIR),
            Pin(num='51',name='PG6',func=pin_types.BIDIR),
            Pin(num='52',name='PG7',func=pin_types.BIDIR),
            Pin(num='53',name='PC0',func=pin_types.BIDIR),
            Pin(num='54',name='PC1',func=pin_types.BIDIR),
            Pin(num='55',name='VDD2',func=pin_types.PWRIN),
            Pin(num='56',name='VSS2',func=pin_types.PWRIN),
            Pin(num='57',name='PC2',func=pin_types.BIDIR),
            Pin(num='58',name='PC3',func=pin_types.BIDIR),
            Pin(num='59',name='PC4',func=pin_types.BIDIR),
            Pin(num='6',name='PA5',func=pin_types.BIDIR),
            Pin(num='60',name='PC5',func=pin_types.BIDIR),
            Pin(num='61',name='PC6',func=pin_types.BIDIR),
            Pin(num='62',name='PC7',func=pin_types.BIDIR),
            Pin(num='63',name='PE6',func=pin_types.BIDIR),
            Pin(num='64',name='PE7',func=pin_types.BIDIR),
            Pin(num='7',name='PA6',func=pin_types.BIDIR),
            Pin(num='8',name='PA7',func=pin_types.BIDIR),
            Pin(num='9',name='VSSA/VREF-',func=pin_types.PWRIN)], 'unit_defs':[] }),
        Part(**{ 'name':'STM8AL3L8AT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM8AL3L8AT'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-80_14x14mm_P0.65mm'], 'footprint':'Package_QFP:LQFP-80_14x14mm_P0.65mm', 'keywords':'STM8 automotive ultra-low-power', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm8al3188.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM8.kicad_sym\nSTM8AL3L8AT\n\nSTM8 automotive ultra-low-power', 'pins':[
            Pin(num='1',name='PH0',func=pin_types.BIDIR),
            Pin(num='10',name='PA5',func=pin_types.BIDIR),
            Pin(num='11',name='PA6',func=pin_types.BIDIR),
            Pin(num='12',name='PA7',func=pin_types.BIDIR),
            Pin(num='13',name='VSSA/VREF-',func=pin_types.PWRIN),
            Pin(num='14',name='VSS1',func=pin_types.PWRIN),
            Pin(num='15',name='VDD1',func=pin_types.PWRIN),
            Pin(num='16',name='VDDA',func=pin_types.PWRIN),
            Pin(num='17',name='VREF+',func=pin_types.PWRIN),
            Pin(num='18',name='PG0',func=pin_types.BIDIR),
            Pin(num='19',name='PG1',func=pin_types.BIDIR),
            Pin(num='2',name='PH1',func=pin_types.BIDIR),
            Pin(num='20',name='PG2',func=pin_types.BIDIR),
            Pin(num='21',name='PG3',func=pin_types.BIDIR),
            Pin(num='22',name='VLCD',func=pin_types.PWRIN),
            Pin(num='23',name='PE0',func=pin_types.BIDIR),
            Pin(num='24',name='PE1',func=pin_types.BIDIR),
            Pin(num='25',name='PE2',func=pin_types.BIDIR),
            Pin(num='26',name='PE3',func=pin_types.BIDIR),
            Pin(num='27',name='PE4',func=pin_types.BIDIR),
            Pin(num='28',name='PE5',func=pin_types.BIDIR),
            Pin(num='29',name='PD0',func=pin_types.BIDIR),
            Pin(num='3',name='PH2',func=pin_types.BIDIR),
            Pin(num='30',name='PD1',func=pin_types.BIDIR),
            Pin(num='31',name='PD2',func=pin_types.BIDIR),
            Pin(num='32',name='PD3',func=pin_types.BIDIR),
            Pin(num='33',name='PH4',func=pin_types.BIDIR),
            Pin(num='34',name='PH5',func=pin_types.BIDIR),
            Pin(num='35',name='PH6',func=pin_types.BIDIR),
            Pin(num='36',name='PH7',func=pin_types.BIDIR),
            Pin(num='37',name='VDD3',func=pin_types.PWRIN),
            Pin(num='38',name='VSS3',func=pin_types.PWRIN),
            Pin(num='39',name='PB0',func=pin_types.BIDIR),
            Pin(num='4',name='PH3',func=pin_types.BIDIR),
            Pin(num='40',name='PB1',func=pin_types.BIDIR),
            Pin(num='41',name='PB2',func=pin_types.BIDIR),
            Pin(num='42',name='PB3',func=pin_types.BIDIR),
            Pin(num='43',name='PB4',func=pin_types.BIDIR),
            Pin(num='44',name='PB5',func=pin_types.BIDIR),
            Pin(num='45',name='PB6',func=pin_types.BIDIR),
            Pin(num='46',name='PB7',func=pin_types.BIDIR),
            Pin(num='47',name='VDD4',func=pin_types.PWRIN),
            Pin(num='48',name='VSS4',func=pin_types.PWRIN),
            Pin(num='49',name='PF0',func=pin_types.BIDIR),
            Pin(num='5',name='PA0',func=pin_types.BIDIR),
            Pin(num='50',name='PF1',func=pin_types.BIDIR),
            Pin(num='51',name='PF2',func=pin_types.BIDIR),
            Pin(num='52',name='PF3',func=pin_types.BIDIR),
            Pin(num='53',name='PF4',func=pin_types.BIDIR),
            Pin(num='54',name='PF5',func=pin_types.BIDIR),
            Pin(num='55',name='PF6',func=pin_types.BIDIR),
            Pin(num='56',name='PF7',func=pin_types.BIDIR),
            Pin(num='57',name='PD4',func=pin_types.BIDIR),
            Pin(num='58',name='PD5',func=pin_types.BIDIR),
            Pin(num='59',name='PD6',func=pin_types.BIDIR),
            Pin(num='6',name='NRST/PA1',func=pin_types.BIDIR),
            Pin(num='60',name='PD7',func=pin_types.BIDIR),
            Pin(num='61',name='PG4',func=pin_types.BIDIR),
            Pin(num='62',name='PG5',func=pin_types.BIDIR),
            Pin(num='63',name='PG6',func=pin_types.BIDIR),
            Pin(num='64',name='PG7',func=pin_types.BIDIR),
            Pin(num='65',name='PC0',func=pin_types.BIDIR),
            Pin(num='66',name='PC1',func=pin_types.BIDIR),
            Pin(num='67',name='VDD2',func=pin_types.PWRIN),
            Pin(num='68',name='VSS2',func=pin_types.PWRIN),
            Pin(num='69',name='PC2',func=pin_types.BIDIR),
            Pin(num='7',name='PA2',func=pin_types.BIDIR),
            Pin(num='70',name='PC3',func=pin_types.BIDIR),
            Pin(num='71',name='PC4',func=pin_types.BIDIR),
            Pin(num='72',name='PC5',func=pin_types.BIDIR),
            Pin(num='73',name='PC6',func=pin_types.BIDIR),
            Pin(num='74',name='PC7',func=pin_types.BIDIR),
            Pin(num='75',name='PE6',func=pin_types.BIDIR),
            Pin(num='76',name='PE7',func=pin_types.BIDIR),
            Pin(num='77',name='PI0',func=pin_types.BIDIR),
            Pin(num='78',name='PI1',func=pin_types.BIDIR),
            Pin(num='79',name='PI2',func=pin_types.BIDIR),
            Pin(num='8',name='PA3',func=pin_types.BIDIR),
            Pin(num='80',name='PI3',func=pin_types.BIDIR),
            Pin(num='9',name='PA4',func=pin_types.BIDIR)], 'unit_defs':[] }),
        Part(**{ 'name':'STM8L051F3P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM8L051F3P'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'STM8L Microcontroller Value Line Low Power', 'description':'', 'datasheet':'http://www.st.com/st-web-ui/static/active/en/resource/technical/document/datasheet/DM00060484.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM8.kicad_sym\nSTM8L051F3P\n\nSTM8L Microcontroller Value Line Low Power', 'pins':[
            Pin(num='1',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA0',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PD0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM8L101F1U', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM8L101F1U'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:ST_UFQFPN-20_3x3mm_P0.5mm'], 'footprint':'Package_DFN_QFN:ST_UFQFPN-20_3x3mm_P0.5mm', 'keywords':'STM8L Microcontroller Value Line Low Power', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm8l101f1.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM8.kicad_sym\nSTM8L101F1U\n\nSTM8L Microcontroller Value Line Low Power', 'pins':[
            Pin(num='1',name='NRST/PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM8L101F2P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM8L101F2P'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'STM8L Microcontroller Value Line Low Power', 'description':'', 'datasheet':'http://www.st.com/st-web-ui/static/active/en/resource/technical/document/datasheet/CD00220591.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM8.kicad_sym\nSTM8L101F2P\n\nSTM8L Microcontroller Value Line Low Power', 'pins':[
            Pin(num='1',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA0',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PD0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM8L151C2T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM8L151C2T'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'STM8 ultra-low-power', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm8l151c3.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM8.kicad_sym\nSTM8L151C2T\n\nSTM8 ultra-low-power', 'pins':[
            Pin(num='1',name='PA0',func=pin_types.BIDIR),
            Pin(num='10',name='VDD',func=pin_types.PWRIN),
            Pin(num='11',name='VDDA',func=pin_types.PWRIN),
            Pin(num='12',name='VREF+',func=pin_types.PWRIN),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT),
            Pin(num='14',name='PE0',func=pin_types.BIDIR),
            Pin(num='15',name='PE1',func=pin_types.BIDIR),
            Pin(num='16',name='PE2',func=pin_types.BIDIR),
            Pin(num='17',name='PE3',func=pin_types.BIDIR),
            Pin(num='18',name='PE4',func=pin_types.BIDIR),
            Pin(num='19',name='PE5',func=pin_types.BIDIR),
            Pin(num='2',name='NRST/PA1',func=pin_types.BIDIR),
            Pin(num='20',name='PD0',func=pin_types.BIDIR),
            Pin(num='21',name='PD1',func=pin_types.BIDIR),
            Pin(num='22',name='PD2',func=pin_types.BIDIR),
            Pin(num='23',name='PD3',func=pin_types.BIDIR),
            Pin(num='24',name='PB0',func=pin_types.BIDIR),
            Pin(num='25',name='PB1',func=pin_types.BIDIR),
            Pin(num='26',name='PB2',func=pin_types.BIDIR),
            Pin(num='27',name='PB3',func=pin_types.BIDIR),
            Pin(num='28',name='PB4',func=pin_types.BIDIR),
            Pin(num='29',name='PB5',func=pin_types.BIDIR),
            Pin(num='3',name='PA2',func=pin_types.BIDIR),
            Pin(num='30',name='PB6',func=pin_types.BIDIR),
            Pin(num='31',name='PB7',func=pin_types.BIDIR),
            Pin(num='32',name='PF0',func=pin_types.BIDIR),
            Pin(num='33',name='PD4',func=pin_types.BIDIR),
            Pin(num='34',name='PD5',func=pin_types.BIDIR),
            Pin(num='35',name='PD6',func=pin_types.BIDIR),
            Pin(num='36',name='PD7',func=pin_types.BIDIR),
            Pin(num='37',name='PC0',func=pin_types.BIDIR),
            Pin(num='38',name='PC1',func=pin_types.BIDIR),
            Pin(num='39',name='VDDIO',func=pin_types.PWRIN),
            Pin(num='4',name='PA3',func=pin_types.BIDIR),
            Pin(num='40',name='VSSIO',func=pin_types.PWRIN),
            Pin(num='41',name='PC2',func=pin_types.BIDIR),
            Pin(num='42',name='PC3',func=pin_types.BIDIR),
            Pin(num='43',name='PC4',func=pin_types.BIDIR),
            Pin(num='44',name='PC5',func=pin_types.BIDIR),
            Pin(num='45',name='PC6',func=pin_types.BIDIR),
            Pin(num='46',name='PC7',func=pin_types.BIDIR),
            Pin(num='47',name='PE6',func=pin_types.BIDIR),
            Pin(num='48',name='PE7',func=pin_types.BIDIR),
            Pin(num='5',name='PA4',func=pin_types.BIDIR),
            Pin(num='6',name='PA5',func=pin_types.BIDIR),
            Pin(num='7',name='PA6',func=pin_types.BIDIR),
            Pin(num='8',name='PA7',func=pin_types.BIDIR),
            Pin(num='9',name='VSS1/VSSA/VREF-',func=pin_types.PWRIN)], 'unit_defs':[] }),
        Part(**{ 'name':'STM8L152R8T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM8L152R8T'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'STM8L Microcontroller Low Power LCD', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm8l152r8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM8.kicad_sym\nSTM8L152R8T\n\nSTM8L Microcontroller Low Power LCD', 'pins':[
            Pin(num='10',name='GND',func=pin_types.PASSIVE),
            Pin(num='21',name='PE2',func=pin_types.BIDIR),
            Pin(num='22',name='PE3',func=pin_types.BIDIR),
            Pin(num='23',name='PE4',func=pin_types.BIDIR),
            Pin(num='24',name='PE5',func=pin_types.BIDIR),
            Pin(num='25',name='PD0',func=pin_types.BIDIR),
            Pin(num='26',name='PD1',func=pin_types.BIDIR),
            Pin(num='27',name='PD2',func=pin_types.BIDIR),
            Pin(num='28',name='PD3',func=pin_types.BIDIR),
            Pin(num='29',name='VDD',func=pin_types.PWRIN),
            Pin(num='30',name='GND',func=pin_types.PWRIN),
            Pin(num='31',name='PB0',func=pin_types.BIDIR),
            Pin(num='32',name='PB1',func=pin_types.BIDIR),
            Pin(num='33',name='PB2',func=pin_types.BIDIR),
            Pin(num='34',name='PB3',func=pin_types.BIDIR),
            Pin(num='35',name='PB4',func=pin_types.BIDIR),
            Pin(num='36',name='PB5',func=pin_types.BIDIR),
            Pin(num='37',name='PB6',func=pin_types.BIDIR),
            Pin(num='38',name='PB7',func=pin_types.BIDIR),
            Pin(num='39',name='PF0',func=pin_types.BIDIR),
            Pin(num='40',name='PF1',func=pin_types.BIDIR),
            Pin(num='41',name='PF4',func=pin_types.BIDIR),
            Pin(num='42',name='PF5',func=pin_types.BIDIR),
            Pin(num='43',name='PF6',func=pin_types.BIDIR),
            Pin(num='44',name='PF7',func=pin_types.BIDIR),
            Pin(num='45',name='PD4',func=pin_types.BIDIR),
            Pin(num='46',name='PD5',func=pin_types.BIDIR),
            Pin(num='47',name='PD6',func=pin_types.BIDIR),
            Pin(num='48',name='PD7',func=pin_types.BIDIR),
            Pin(num='49',name='PG4',func=pin_types.BIDIR),
            Pin(num='50',name='PG5',func=pin_types.BIDIR),
            Pin(num='51',name='PG6',func=pin_types.BIDIR),
            Pin(num='52',name='PG7',func=pin_types.BIDIR),
            Pin(num='53',name='PC0',func=pin_types.BIDIR),
            Pin(num='54',name='PC1',func=pin_types.BIDIR),
            Pin(num='55',name='VDD',func=pin_types.PWRIN),
            Pin(num='56',name='GND',func=pin_types.PASSIVE),
            Pin(num='57',name='PC2',func=pin_types.BIDIR),
            Pin(num='58',name='PC3',func=pin_types.BIDIR),
            Pin(num='59',name='PC4',func=pin_types.BIDIR),
            Pin(num='60',name='PC5',func=pin_types.BIDIR),
            Pin(num='61',name='PC6',func=pin_types.BIDIR),
            Pin(num='62',name='PC7',func=pin_types.BIDIR),
            Pin(num='63',name='PE6',func=pin_types.BIDIR),
            Pin(num='64',name='PE7',func=pin_types.BIDIR),
            Pin(num='1',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VREF+',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VLCD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='NRST/PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSSA/VREF-',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM8S001J3M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM8S001J3M'}), 'ref_prefix':'U', 'fplist':['Package_SO:SO-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SO-8_3.9x4.9mm_P1.27mm', 'keywords':'STM8 Microcontroller Value Line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm8s001j3.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM8.kicad_sym\nSTM8S001J3M\n\nSTM8 Microcontroller Value Line', 'pins':[
            Pin(num='1',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM8S003F3P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM8S003F3P'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'STM8S Mainstream Value line 8-bit, 16MHz, 1k RAM, 128 EEPROM', 'description':'', 'datasheet':'http://www.st.com/st-web-ui/static/active/en/resource/technical/document/datasheet/DM00024550.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM8.kicad_sym\nSTM8S003F3P\n\nSTM8S Mainstream Value line 8-bit, 16MHz, 1k RAM, 128 EEPROM', 'pins':[
            Pin(num='1',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM8S003F3U', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM8S003F3U'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:ST_UFQFPN-20_3x3mm_P0.5mm'], 'footprint':'Package_DFN_QFN:ST_UFQFPN-20_3x3mm_P0.5mm', 'keywords':'STM8S Mainstream Value line 8-bit, 16MHz, 1k RAM, 128 EEPROM', 'description':'', 'datasheet':'http://www.st.com/st-web-ui/static/active/en/resource/technical/document/datasheet/DM00024550.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM8.kicad_sym\nSTM8S003F3U\n\nSTM8S Mainstream Value line 8-bit, 16MHz, 1k RAM, 128 EEPROM', 'pins':[
            Pin(num='1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM8S003K3T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM8S003K3T'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'STM8 Microcontroller Value Line', 'description':'', 'datasheet':'http://www.st.com/st-web-ui/static/active/en/resource/technical/document/datasheet/DM00024550.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM8.kicad_sym\nSTM8S003K3T\n\nSTM8 Microcontroller Value Line', 'pins':[
            Pin(num='1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VCAP',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM8S207MB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM8S207MB'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-80_14x14mm_P0.65mm'], 'footprint':'Package_QFP:LQFP-80_14x14mm_P0.65mm', 'keywords':'STM8 Microcontroller Performance Line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm8s207mb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM8.kicad_sym\nSTM8S207MB\n\nSTM8 Microcontroller Performance Line', 'pins':[
            Pin(num='13',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VREF+',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='VREF-',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSSIO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VSSIO_2',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VDDIO_2',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='50',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VCAP',func=pin_types.INPUT,unit=1),
            Pin(num='63',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='70',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VDDIO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM8S208CB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM8S208CB'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'STM8 Microcontroller Performance Line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm8s208cb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM8.kicad_sym\nSTM8S208CB\n\nSTM8 Microcontroller Performance Line', 'pins':[
            Pin(num='1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSSIO_2',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VDDIO_2',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSSIO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VCAP',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VDDIO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM8S208RB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM8S208RB'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'STM8 Microcontroller Performance Line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm8s208rb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM8.kicad_sym\nSTM8S208RB\n\nSTM8 Microcontroller Performance Line', 'pins':[
            Pin(num='1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VREF+',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF-',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='VSSIO_2',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSSIO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='VDDIO_2',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='50',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VCAP',func=pin_types.INPUT,unit=1),
            Pin(num='60',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VDDIO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM8L101F2U', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM8L101F2U'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:ST_UFQFPN-20_3x3mm_P0.5mm', 'Package_DFN_QFN:ST_UFQFPN-20_3x3mm_P0.5mm'], 'footprint':'Package_DFN_QFN:ST_UFQFPN-20_3x3mm_P0.5mm', 'keywords':'STM8L Microcontroller Value Line Low Power', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm8l101f1.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM8.kicad_sym\nSTM8L101F2U\n\nSTM8L Microcontroller Value Line Low Power', 'pins':[
            Pin(num='1',name='NRST/PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM8L101F3P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM8L101F3P'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'STM8L Microcontroller Value Line Low Power', 'description':'', 'datasheet':'http://www.st.com/st-web-ui/static/active/en/resource/technical/document/datasheet/CD00220591.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM8.kicad_sym\nSTM8L101F3P\n\nSTM8L Microcontroller Value Line Low Power', 'pins':[
            Pin(num='1',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA0',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PD0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM8L101F3U', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM8L101F3U'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:ST_UFQFPN-20_3x3mm_P0.5mm', 'Package_DFN_QFN:ST_UFQFPN-20_3x3mm_P0.5mm', 'Package_DFN_QFN:ST_UFQFPN-20_3x3mm_P0.5mm'], 'footprint':'Package_DFN_QFN:ST_UFQFPN-20_3x3mm_P0.5mm', 'keywords':'STM8L Microcontroller Value Line Low Power', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm8l101f1.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM8.kicad_sym\nSTM8L101F3U\n\nSTM8L Microcontroller Value Line Low Power', 'pins':[
            Pin(num='1',name='NRST/PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM8L151C3T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM8L151C3T'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'STM8 ultra-low-power', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm8l151c3.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM8.kicad_sym\nSTM8L151C3T\n\nSTM8 ultra-low-power', 'pins':[
            Pin(num='1',name='PA0',func=pin_types.BIDIR),
            Pin(num='10',name='VDD',func=pin_types.PWRIN),
            Pin(num='11',name='VDDA',func=pin_types.PWRIN),
            Pin(num='12',name='VREF+',func=pin_types.PWRIN),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT),
            Pin(num='14',name='PE0',func=pin_types.BIDIR),
            Pin(num='15',name='PE1',func=pin_types.BIDIR),
            Pin(num='16',name='PE2',func=pin_types.BIDIR),
            Pin(num='17',name='PE3',func=pin_types.BIDIR),
            Pin(num='18',name='PE4',func=pin_types.BIDIR),
            Pin(num='19',name='PE5',func=pin_types.BIDIR),
            Pin(num='2',name='NRST/PA1',func=pin_types.BIDIR),
            Pin(num='20',name='PD0',func=pin_types.BIDIR),
            Pin(num='21',name='PD1',func=pin_types.BIDIR),
            Pin(num='22',name='PD2',func=pin_types.BIDIR),
            Pin(num='23',name='PD3',func=pin_types.BIDIR),
            Pin(num='24',name='PB0',func=pin_types.BIDIR),
            Pin(num='25',name='PB1',func=pin_types.BIDIR),
            Pin(num='26',name='PB2',func=pin_types.BIDIR),
            Pin(num='27',name='PB3',func=pin_types.BIDIR),
            Pin(num='28',name='PB4',func=pin_types.BIDIR),
            Pin(num='29',name='PB5',func=pin_types.BIDIR),
            Pin(num='3',name='PA2',func=pin_types.BIDIR),
            Pin(num='30',name='PB6',func=pin_types.BIDIR),
            Pin(num='31',name='PB7',func=pin_types.BIDIR),
            Pin(num='32',name='PF0',func=pin_types.BIDIR),
            Pin(num='33',name='PD4',func=pin_types.BIDIR),
            Pin(num='34',name='PD5',func=pin_types.BIDIR),
            Pin(num='35',name='PD6',func=pin_types.BIDIR),
            Pin(num='36',name='PD7',func=pin_types.BIDIR),
            Pin(num='37',name='PC0',func=pin_types.BIDIR),
            Pin(num='38',name='PC1',func=pin_types.BIDIR),
            Pin(num='39',name='VDDIO',func=pin_types.PWRIN),
            Pin(num='4',name='PA3',func=pin_types.BIDIR),
            Pin(num='40',name='VSSIO',func=pin_types.PWRIN),
            Pin(num='41',name='PC2',func=pin_types.BIDIR),
            Pin(num='42',name='PC3',func=pin_types.BIDIR),
            Pin(num='43',name='PC4',func=pin_types.BIDIR),
            Pin(num='44',name='PC5',func=pin_types.BIDIR),
            Pin(num='45',name='PC6',func=pin_types.BIDIR),
            Pin(num='46',name='PC7',func=pin_types.BIDIR),
            Pin(num='47',name='PE6',func=pin_types.BIDIR),
            Pin(num='48',name='PE7',func=pin_types.BIDIR),
            Pin(num='5',name='PA4',func=pin_types.BIDIR),
            Pin(num='6',name='PA5',func=pin_types.BIDIR),
            Pin(num='7',name='PA6',func=pin_types.BIDIR),
            Pin(num='8',name='PA7',func=pin_types.BIDIR),
            Pin(num='9',name='VSS1/VSSA/VREF-',func=pin_types.PWRIN)], 'unit_defs':[] }),
        Part(**{ 'name':'STM8L152R6T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM8L152R6T'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'STM8L Microcontroller Low Power LCD', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm8l152r6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM8.kicad_sym\nSTM8L152R6T\n\nSTM8L Microcontroller Low Power LCD', 'pins':[
            Pin(num='10',name='GND',func=pin_types.PASSIVE),
            Pin(num='21',name='PE2',func=pin_types.BIDIR),
            Pin(num='22',name='PE3',func=pin_types.BIDIR),
            Pin(num='23',name='PE4',func=pin_types.BIDIR),
            Pin(num='24',name='PE5',func=pin_types.BIDIR),
            Pin(num='25',name='PD0',func=pin_types.BIDIR),
            Pin(num='26',name='PD1',func=pin_types.BIDIR),
            Pin(num='27',name='PD2',func=pin_types.BIDIR),
            Pin(num='28',name='PD3',func=pin_types.BIDIR),
            Pin(num='29',name='VDD',func=pin_types.PWRIN),
            Pin(num='30',name='GND',func=pin_types.PWRIN),
            Pin(num='31',name='PB0',func=pin_types.BIDIR),
            Pin(num='32',name='PB1',func=pin_types.BIDIR),
            Pin(num='33',name='PB2',func=pin_types.BIDIR),
            Pin(num='34',name='PB3',func=pin_types.BIDIR),
            Pin(num='35',name='PB4',func=pin_types.BIDIR),
            Pin(num='36',name='PB5',func=pin_types.BIDIR),
            Pin(num='37',name='PB6',func=pin_types.BIDIR),
            Pin(num='38',name='PB7',func=pin_types.BIDIR),
            Pin(num='39',name='PF0',func=pin_types.BIDIR),
            Pin(num='40',name='PF1',func=pin_types.BIDIR),
            Pin(num='41',name='PF4',func=pin_types.BIDIR),
            Pin(num='42',name='PF5',func=pin_types.BIDIR),
            Pin(num='43',name='PF6',func=pin_types.BIDIR),
            Pin(num='44',name='PF7',func=pin_types.BIDIR),
            Pin(num='45',name='PD4',func=pin_types.BIDIR),
            Pin(num='46',name='PD5',func=pin_types.BIDIR),
            Pin(num='47',name='PD6',func=pin_types.BIDIR),
            Pin(num='48',name='PD7',func=pin_types.BIDIR),
            Pin(num='49',name='PG4',func=pin_types.BIDIR),
            Pin(num='50',name='PG5',func=pin_types.BIDIR),
            Pin(num='51',name='PG6',func=pin_types.BIDIR),
            Pin(num='52',name='PG7',func=pin_types.BIDIR),
            Pin(num='53',name='PC0',func=pin_types.BIDIR),
            Pin(num='54',name='PC1',func=pin_types.BIDIR),
            Pin(num='55',name='VDD',func=pin_types.PWRIN),
            Pin(num='56',name='GND',func=pin_types.PASSIVE),
            Pin(num='57',name='PC2',func=pin_types.BIDIR),
            Pin(num='58',name='PC3',func=pin_types.BIDIR),
            Pin(num='59',name='PC4',func=pin_types.BIDIR),
            Pin(num='60',name='PC5',func=pin_types.BIDIR),
            Pin(num='61',name='PC6',func=pin_types.BIDIR),
            Pin(num='62',name='PC7',func=pin_types.BIDIR),
            Pin(num='63',name='PE6',func=pin_types.BIDIR),
            Pin(num='64',name='PE7',func=pin_types.BIDIR),
            Pin(num='1',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VREF+',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VLCD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='NRST/PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSSA/VREF-',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM8S207C6', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM8S207C6'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'STM8 Microcontroller Performance Line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm8s208cb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM8.kicad_sym\nSTM8S207C6\n\nSTM8 Microcontroller Performance Line', 'pins':[
            Pin(num='1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSSIO_2',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VDDIO_2',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSSIO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VCAP',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VDDIO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM8S207C8', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM8S207C8'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'STM8 Microcontroller Performance Line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm8s208cb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM8.kicad_sym\nSTM8S207C8\n\nSTM8 Microcontroller Performance Line', 'pins':[
            Pin(num='1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSSIO_2',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VDDIO_2',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSSIO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VCAP',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VDDIO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM8S207CB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM8S207CB'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'STM8 Microcontroller Performance Line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm8s208cb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM8.kicad_sym\nSTM8S207CB\n\nSTM8 Microcontroller Performance Line', 'pins':[
            Pin(num='1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSSIO_2',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VDDIO_2',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSSIO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VCAP',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VDDIO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM8S207R6', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM8S207R6'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'STM8 Microcontroller Performance Line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm8s208rb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM8.kicad_sym\nSTM8S207R6\n\nSTM8 Microcontroller Performance Line', 'pins':[
            Pin(num='1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VREF+',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF-',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='VSSIO_2',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSSIO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='VDDIO_2',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='50',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VCAP',func=pin_types.INPUT,unit=1),
            Pin(num='60',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VDDIO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM8S207R8', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM8S207R8'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'STM8 Microcontroller Performance Line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm8s208rb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM8.kicad_sym\nSTM8S207R8\n\nSTM8 Microcontroller Performance Line', 'pins':[
            Pin(num='1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VREF+',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF-',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='VSSIO_2',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSSIO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='VDDIO_2',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='50',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VCAP',func=pin_types.INPUT,unit=1),
            Pin(num='60',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VDDIO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM8S207RB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM8S207RB'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'STM8 Microcontroller Performance Line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm8s208rb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM8.kicad_sym\nSTM8S207RB\n\nSTM8 Microcontroller Performance Line', 'pins':[
            Pin(num='1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VREF+',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF-',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='VSSIO_2',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSSIO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='VDDIO_2',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='50',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VCAP',func=pin_types.INPUT,unit=1),
            Pin(num='60',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VDDIO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM8S208C6', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM8S208C6'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'STM8 Microcontroller Performance Line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm8s208cb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM8.kicad_sym\nSTM8S208C6\n\nSTM8 Microcontroller Performance Line', 'pins':[
            Pin(num='1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSSIO_2',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VDDIO_2',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSSIO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VCAP',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VDDIO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM8S208C8', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM8S208C8'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'STM8 Microcontroller Performance Line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm8s208cb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM8.kicad_sym\nSTM8S208C8\n\nSTM8 Microcontroller Performance Line', 'pins':[
            Pin(num='1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSSIO_2',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VDDIO_2',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSSIO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VCAP',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VDDIO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM8S208MB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM8S208MB'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-80_14x14mm_P0.65mm', 'Package_QFP:LQFP-80_14x14mm_P0.65mm'], 'footprint':'Package_QFP:LQFP-80_14x14mm_P0.65mm', 'keywords':'STM8 Microcontroller Performance Line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm8s208mb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM8.kicad_sym\nSTM8S208MB\n\nSTM8 Microcontroller Performance Line', 'pins':[
            Pin(num='13',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VREF+',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='VREF-',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSSIO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VSSIO_2',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VDDIO_2',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='50',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VCAP',func=pin_types.INPUT,unit=1),
            Pin(num='63',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='70',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VDDIO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM8S208R6', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM8S208R6'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'STM8 Microcontroller Performance Line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm8s208rb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM8.kicad_sym\nSTM8S208R6\n\nSTM8 Microcontroller Performance Line', 'pins':[
            Pin(num='1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VREF+',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF-',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='VSSIO_2',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSSIO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='VDDIO_2',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='50',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VCAP',func=pin_types.INPUT,unit=1),
            Pin(num='60',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VDDIO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM8S208R8', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM8S208R8'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'STM8 Microcontroller Performance Line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm8s208rb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM8.kicad_sym\nSTM8S208R8\n\nSTM8 Microcontroller Performance Line', 'pins':[
            Pin(num='1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VREF+',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF-',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='VSSIO_2',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSSIO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='VDDIO_2',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='50',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VCAP',func=pin_types.INPUT,unit=1),
            Pin(num='60',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VDDIO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] })])